xquery version "1.0";
declare default element namespace "http://www.tei-c.org/ns/1.0";
declare namespace transform = "http://exist-db.org/xquery/transform";
declare option exist:serialize "indent=yes media-type=text/html method=xhtml doctype-public=-//W3C//DTD&#160;XHTML&#160;1.1//EN doctype-system=http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd";

(: this function returns the appropriate cluster from the comcat:)
declare function local:GetDepedency($base as xs:string) as element()
{
   let $dep := document("/bza/comCatBza.xml")/TEI/text/body/list/item/list[@xml:id=$base]
   return $dep
};

(: GetPrev and GetNext are the two functions needed to pass the base of the previous and the next sutra into the XML output, which the stylesheet needs to create the previous and next links :)
declare function local:GetPrev($prev as xs:integer) as xs:string
{
let $prev := $prev
return
  if ($prev <= 9) then concat("00", $prev) else
           if ($prev > 99) then  (xs:string($prev)) else concat("0", $prev)
  } ;
declare function local:GetNext($next as xs:integer) as xs:string
{
let $next := $next
return
  if ($next <= 9) then concat("00", $next) else
           if ($next > 99) then  (xs:string($next)) else concat("0", $next)
  } ;



(: this function constructs a TEI document in memory from which is transformed into html by the transform:transform function below :)
declare function local:GenerateXML($r1 as xs:string,$r2 as xs:string, $dep as element()) as element()
{
let  $doc1 :=  concat ("/db/bza/",$r1)
let  $doc2 :=  concat ("/db/bza/",$r2)
let $docH := document($doc1)/TEI/teiHeader
let $doc1B := document($doc1)/TEI/text
let $doc2B := document($doc2)/TEI/text

let $doc1B:= if (fn:empty($doc1B)) then <text></text> else $doc1B
let $doc2B:= if (fn:empty($doc2B)) then <text></text> else $doc2B

(:this smuggels the numbers of the previous and next sutra into the XML tree so that the stylesheet can use them conveniently:)
let $base := request:request-parameter("base", "bza001")
let $baseNo := xs:integer(substring-after($base, "bza"))
let $prev := data($baseNo - 1)
let $next := data($baseNo + 1)

return <TEI>
                   <teiHeader> {$docH} </teiHeader>
                   <prev>{local:GetPrev($prev)}</prev>
                   <next>{local:GetNext($next)}</next>
                    <text>
                        <front>
                           <docTitle>{data($dep/head)} </docTitle>
                            <argument>
                                <list xml:id="all">
                                  {
                                    for $x in $dep/item
                                    return <item value="{data($x/ref/@target)}">{$x/ref/seg}</item>
                                  }
                                </list>
                                <list xml:id="selected">
                                  {
                                     for $y in $dep/item/ref[@target=$r1]
                                     return <item value="{$r1}">{$y/seg}</item>
                                  }
                                  {
                                     for $y in $dep/item/ref[@target=$r2]
                                     return <item value="{$r2}">{$y/seg}</item>
                                  }

                                </list>
                             </argument>
                        </front>
                        <group>
                            {$doc1B}
                            {$doc2B}

                        </group>
                    </text>
            </TEI>
};

(: This gets the parameter from the web-page interface, the second argument is the default:)
let $base := request:request-parameter("base", "bza001")
let $dep := local:GetDepedency($base)

(: "doc1" etc. come from the select-form button on top of each colum in the web-interface :)
let $r1 := request:request-parameter("doc1", data($dep/item[1]/ref/@target)),
     $r2 := request:request-parameter("doc2", data($dep/item[2]/ref/@target))


let $clusterdoc := local:GenerateXML($r1,$r2,$dep) ,
        $xls := document('/db/bza/bzaXSLp5-clusterpage2col.xsl'),
        $params :=
        <parameters>
        </parameters>
       (: this return function  give the above $clusterdoc (as constructed in memory), transforms it with the  stylesheet specified in $xls, parameters might be given here but are not:)
       return transform:transform($clusterdoc,$xls,$params)
